@@ -33,9 +33,25 @@ Switches:
         
     -e  
         External routin used (do print otherwize),        Filename will be
-        substituted indeed substring %(name)s in this string. It supposed
+        substituted indeed substring %(file)s in this string. It supposed
         running program read filename when started and write after finish;
         
+        There are other names to substitute:
+        
+            file
+                Full path to file on disk;
+                
+            path
+                Path to object on xmlrpcserver;
+                
+            name
+                Name of object in xmlrpcserver.                                
+                
+
+    -q <INT>
+          
+        Skip first objects;   
+                
         
 Arguments:
 
@@ -50,9 +66,9 @@ Arguments:
 Sample::
 
     ngxmlrpcscan.py -s -p -v \
-        -i zope.app.folder.folder.Folder
-        -с zope.dublincore.interfaces.IZopeDublinCore \
-        -e "joe  %(name)s "
+        -c zope.app.folder.folder.Folder
+        -i zope.dublincore.interfaces.IZopeDublinCore \
+        -e "joe  %(file)s "
         http://theman:12345678@localhost:8080/Root/Main \
          title description        
        
@@ -61,17 +77,18 @@ The ngxmlrpcscan scaned object tree rooted in
 http://theman:12345678@localhost:8080/Root/Main to find all folders and to
 edit folder methadata via IZopeDublinCore adapter.
 
-$Id: ngxmlrpcscan.py 13261 2007-11-23 01:52:07Z cray $
+$Id: ngxmlrpcscan.py 51898 2008-10-21 11:36:39Z cray $
 """
 __author__  = "Andrey Orlov"
 __license__ = "GPL"
-__version__ = "$Revision: 13261 $"
+__version__ = "$Revision: 51898 $"
 
 def _(s) : return s
 
 from xmlrpclib import ServerProxy, Error
 import getopt, fcntl, signal, sys, os, tempfile
 from urllib import quote,unquote
+from urlparse import urlparse,urlunparse
 
 def walk(rpcserver,attributes,klass,interface='zope.interface.Interface') :        
     server = ServerProxy(rpcserver)
@@ -90,16 +107,19 @@ def main() :
     isedit = False
     isnotscan = False
     execute = None
-    
+    skip = 0 
+        
     interface = 'zope.interface.Interface'
     klass = None
-    opts,vals = getopt.getopt(sys.argv[1:],"vpsne:c:i:") 
+    opts,vals = getopt.getopt(sys.argv[1:],"vpsne:c:i:q:") 
 
     if len(vals) <= 1 :
         print __doc__
         return 0
         
-    rpcserver = vals[0]
+    l = urlparse(vals[0])
+    rpcserver = urlunparse(l[0:2] + (quote(l[2]),)+l[3:])
+
     attributes = vals[1:]
 
     for opt,val in opts :
@@ -117,12 +137,15 @@ def main() :
             isnotscan = True
         elif opt in ["-e"] :
             execute = val
+        elif opt in ["-q"] :
+            skip = int(val)
         else :
             print >>sys.stderr, "Unknown key %s" % opt
 
     if isverbose :
         print "Begin file scan"
 
+
     if isnotscan :
         lg = ( (rpcserver,ServerProxy(rpcserver),x) for x in attributes )
     else :      
@@ -134,16 +157,27 @@ def main() :
             print "    ", server.klass()
             print "    ", attr
             print "-" * 80
-        value = server.getattr(interface,attr) 
 
-        if execute :
-            fn=tempfile.mktemp()+"-"+".".join(unquote(path[len(rpcserver):]).split("/"))
+        try :
+            value = server.getattr(interface,attr) 
+        except Exception,msg :
+            print "Getattr",interface,attr,"fault:",msg
+            continue            
+
+
+        if skip :
+            skip -= 1
+        elif execute :
+            path = unquote(path[len(rpcserver):])
+            name = path.split("/")[-1]
+            fn=tempfile.mktemp()+"-"+".".join(path.split("/"))
+
             open(fn,"w").write(value)
             if ispause :
                 print "Please, enter:"
                 sys.stdin.readline()
         
-            os.system(execute % {"name":fn })
+            os.system(execute % {"file":fn,"path":path,"name":name })
             if isedit :
                 value = open(fn,"r").read()
                 server.setattr(interface,attr,value)
